.. This toctree will be displayed on all docs/ pages

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Guides

   Quickstart <guides/quickstart>
   Tips & Tricks <guides/tips-and-tricks>
   Troubleshooting <guides/troubleshooting>
   Advanced Integration <guides/advanced-integration>
   Migration from Misaka to Mistune <guides/mistune>
   FAQ <guides/faq>

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Reference

   Installation <reference/installation>
   Server Configuration <reference/server-config>
   Client Configuration <reference/client-config>
   Markdown Configuration <reference/markdown-config>
   Deployment <reference/deployment>
   Multiple Sites & Sub-URI <reference/multi-site-sub-uri>
   Server API <reference/server-api>
   Releasing <reference/releasing>

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Technical documentation

   Server <technical-docs/server>
   Client <technical-docs/client>
   Development & Testing <technical-docs/testing>
   Testing the Client <technical-docs/testing-client>
   Testing the Server <technical-docs/testing-server>

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Contributing

   Contributing to Isso <contributing/index>
   Writing Documentation <contributing/documentation>
   Isso Project Infrastructure <contributing/infrastructure>
